<?php
/**
 * Nexter Builder Display Conditional Rules
 *
 * @package Nexter Extensions
 * @since 1.0.0
 */
if ( ! class_exists( 'Nexter_Builder_Display_Conditional_Rules' ) ) {

	class Nexter_Builder_Display_Conditional_Rules {


		/**
		 * Instance
		 */
		private static $instance;
		
		/**
		 * Location Rules Options
		 */
		private static $location_rules_options;
		
		/**
		 * Current page type
		 */
		private static $current_page_type_name = null;
		
		/**
		 * Current page type singular
		 */
		private static $current_page_type_name_singular = null;
		
		/**
		 * Current page type archive
		 */
		private static $current_page_type_name_archive = null;

		/**
		 * Current page data
		 */
		private static $current_load_page_data = [];

		/**
		 * Current singular page data
		 */
		private static $current_singular_data = [];

		/**
		 * Current archive page data
		 */
		private static $current_archive_data = [];
		
		/**
		 * Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self;
			}

			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {
			add_action( 'admin_action_edit', array( $this, 'init_options' ) );
		}

		/**
		 * Initialize Options
		 */
		public function init_options() {
			self::$location_rules_options = self::get_location_rules_options();
		}
		
		/**
		 * Get location selection options.
		 *
		 * @since 1.0.0
		 */
		public static function get_location_rules_options() {

			$options = array(
				'standard'         => array(
					'label' => __( 'Standard', 'nexter-ext' ),
					'value' => array(
						'standard-universal'	=> __( 'Entire Website', 'nexter-ext' ),
					),
				),
			);
			
			return  apply_filters( 'nexter_location_rules_list', $options );
		}

		/**
		 * Display Label Location by section.
		 *
		 * @since 1.0.0
		 */
		public static function display_label_location_by_key( $section ) {
			if ( ! isset( self::$location_rules_options ) || empty( self::$location_rules_options ) ) {
				self::$location_rules_options = self::get_location_rules_options();
			}
			
			foreach ( self::$location_rules_options as $group ) {
				if ( isset( $group['value'][ $section ] ) ) {
					return $group['value'][ $section ];
				}
			}
			
			// Display Post title By section location 
			if ( strpos( $section, 'post-' ) !== false ) {
				$post_id = (int) str_replace( 'post-', '', $section );
				return get_the_title( $post_id );
			}

			// Display Taxonomy Name By section location
			if ( strpos( $section, 'taxonomy-' ) !== false ) {
				$tax_id = (int) str_replace( 'taxonomy-', '', $section );
				$term   = get_term( $tax_id );

				if ( ! is_wp_error( $term ) ) {
					$term_taxonomy = ucfirst( str_replace( '_', ' ', $term->taxonomy ) );
					return $term->name . ' - ' . $term_taxonomy;
				} else {
					return '';
				}
			}

			return $section;
		}

		/**
		 * Checks for Current Page By Display Condition Rules
		 *
		 * @since 1.0.0
		 */
		public function check_layout_display_inc_exc_rules( $post_id, $conditions ) {

			$current_post_type = get_post_type( $post_id );
			$display           = false;

			if ( isset( $conditions ) && is_array( $conditions ) && ! empty( $conditions ) ) {
			
				foreach ( $conditions as $key => $condition ) {

					if ( !is_array($condition) && strrpos( $condition, 'entire' ) !== false ) {
						$check_cond = 'entire';
					} else {
						$check_cond = $condition;
					}

					if( !empty($check_cond) ){
						if( $check_cond == 'standard-universal' ){
							$display = true;
						}else if( $check_cond == 'entire' ){
						
							$condition_data = explode( '|', $condition );

							$post_type     = isset( $condition_data[0] ) ? $condition_data[0] : false;
							$archive  = isset( $condition_data[2] ) ? $condition_data[2] : false;
							$taxonomy      = isset( $condition_data[3] ) ? $condition_data[3] : false;
							
							if ( $archive  === false ) {
								$current_post_type = get_post_type( $post_id );

								if ( $post_id !== false && $current_post_type == $post_type ) {
									$display = true;
								}
							} else {

								if ( is_archive() ) {
									$current_post_type = get_post_type();
									if ( $current_post_type == $post_type ) {
										if ( $archive  == 'archive' ) {
											$display = true;
										} else if ( $archive  == 'tax-archive' ) {

											$object	= get_queried_object();
											$object_taxonomy = '';
											if ( $object !== '' && $object !== null) {
												$object_taxonomy = $object->taxonomy;
											}

											if ( $object_taxonomy == $taxonomy ) {
												$display = true;
											}
										}
									}
								}
							}
						}else if(defined('NXT_PRO_EXT_VER')){
							$display = apply_filters('nexter_advanced_layout_display_condition', $display, $check_cond, $conditions, $post_id );
						}
					}
					
					if ( $display ) {
						break;
					}
				}
			}

			return $display;
		}

		/**
		 * Get Check Current Page Type / Singular / Archive
		 *
		 * @since  1.0.0
		 */
		public function get_check_current_page_type_name( $type = '' ) {

			if ( (empty($type) && null === self::$current_page_type_name) || ($type=='singular' && null === self::$current_page_type_name_singular) || ($type=='archive' && null === self::$current_page_type_name_archive) ) {

				$current_id = false;
				$page_type  = '';

				if ( is_home() ) {
					$page_type = 'is_home';
				} elseif ( is_front_page() ) {
					$page_type  = 'is_front_page';
					$current_id = get_the_id();
				} elseif ( is_singular() ) {
					$page_type  = 'is_singular';
					$current_id = get_the_id();
				} elseif ( is_archive() ) {
					$page_type = 'is_archive';

					if ( is_category() || is_tag() || is_tax() ) {
						$page_type = 'is_tax';
					} elseif ( is_date() ) {
						$page_type = 'is_date';
					} elseif ( is_author() ) {
						$page_type = 'is_author';
					} elseif ( function_exists( 'is_shop' ) && is_shop() ) {
						$page_type = 'is_shop_page';
					}
				}else if ( is_404() ) {
					$page_type = 'is_404';
				}else if ( is_search() ) {
					$page_type = 'is_search';
				} else {
					$current_id = get_the_id();
				}
				
				if( !empty($type) && $type=='singular' ){
					self::$current_singular_data['ID'] = $current_id;
					self::$current_page_type_name_singular = $page_type;
				}else if( !empty($type) && $type=='archive' ){
					self::$current_archive_data['ID'] = $current_id;
					self::$current_page_type_name_archive = $page_type;
				}else if(empty($type)){
					self::$current_load_page_data['ID'] = $current_id;
					self::$current_page_type_name       = $page_type;
				}
			}
			
			if( !empty($type) && $type=='singular' ){
				return self::$current_page_type_name_singular;
			}else if(!empty($type) && $type=='archive'){
				return self::$current_page_type_name_archive;
			}else{
				return self::$current_page_type_name;
			}
		}
		
		/*
		 * Get Singular Template(Posts) By Singular Options Conditions
		 *
		 * @since  1.0.0
		 */
		public function get_templates_by_singular_conditions( $type, $options ){
			global $wpdb;
			global $post;

			$type = $type ? esc_sql( $type ) : esc_sql( $post->post_type );

			if ( is_array( self::$current_singular_data ) && isset( self::$current_singular_data[ $type ] ) ) {
				return apply_filters( 'nexter_get_singluar_posts_by_conditions', self::$current_singular_data[ $type ], $type );
			}

			$current_page_type_name_singular = $this->get_check_current_page_type_name('singular');

			self::$current_singular_data[ $type ] = array();

			$options['current_post_id'] = self::$current_singular_data['ID'];


			$singular_group = isset( $options['singular_group'] ) ? esc_sql( $options['singular_group'] ) : '';

			$sqlquery = "SELECT p.ID, pm.meta_value FROM {$wpdb->postmeta} as pm INNER JOIN {$wpdb->posts} as p ON pm.post_id = p.ID WHERE (pm.meta_key = %s) AND p.post_type = %s AND p.post_status = 'publish' ORDER BY p.post_date DESC";
			
			$sql1 = $wpdb->prepare( $sqlquery , $singular_group, $type );	// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared
			
			$posts  = $wpdb->get_results( $sql1 );	// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared

			foreach ( $posts as $post_data ) {
				$get_layout_type = get_post_meta( $post_data->ID , 'nxt-hooks-layout-pages', false );
				if(!empty($get_layout_type) && !empty($get_layout_type[0]) && 'singular' == $get_layout_type[0]){
					self::$current_singular_data[ $type ][ $post_data->ID ] = array(
						'id'       => $post_data->ID,
						'template_group' => maybe_unserialize( $post_data->meta_value ),
					);
				}
			}
			
			return apply_filters( 'nexter_get_singluar_posts_by_conditions', self::$current_singular_data[ $type ], $type );
		}
		
		/*
		 * Get Archives Template(Posts) By Archives Options Conditions
		 *
		 * @since 1.0.0
		 */
		public function get_templates_by_archives_conditions( $type, $options ){
			global $wpdb;
			global $post;

			$type = $type ? esc_sql( $type ) : esc_sql( $post->post_type );

			if ( is_array( self::$current_archive_data ) && isset( self::$current_archive_data[ $type ] ) ) {
				return apply_filters( 'nexter_get_archive_posts_by_conditions', self::$current_archive_data[ $type ], $type );
			}

			$current_page_type_name_archive = $this->get_check_current_page_type_name('archive');

			self::$current_archive_data[ $type ] = array();

			$options['current_post_id'] = self::$current_archive_data['ID'];

			$archive_group = isset( $options['archive_group'] ) ? esc_sql( $options['archive_group'] ) : '';

			$sqlquery = "SELECT p.ID, pm.meta_value FROM {$wpdb->postmeta} as pm INNER JOIN {$wpdb->posts} as p ON pm.post_id = p.ID WHERE (pm.meta_key = %s) AND p.post_type = %s AND p.post_status = 'publish' ORDER BY p.post_date DESC";
			
			$sql2 = $wpdb->prepare( $sqlquery , $archive_group, $type );	// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared
			
			$posts  = $wpdb->get_results( $sql2 );	// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared

			foreach ( $posts as $post_data ) {
				$get_layout_type = get_post_meta( $post_data->ID , 'nxt-hooks-layout-pages', false );
				if( !empty($get_layout_type) && !empty($get_layout_type[0]) && 'archives' == $get_layout_type[0]){
					self::$current_archive_data[ $type ][ $post_data->ID ] = array(
						'id'       => $post_data->ID,
						'template_group' => maybe_unserialize( $post_data->meta_value ),
					);
				}
			}
			
			return apply_filters( 'nexter_get_archive_posts_by_conditions', self::$current_archive_data[ $type ], $type );
		}
		
		/**
		 * Get Template posts by Sections conditions
		 *
		 * @since 1.0.0
		 */
		public function get_templates_by_sections_conditions( $type, $option ) {

			global $wpdb;
			global $post;

			$type = $type ? esc_sql( $type ) : esc_sql( $post->post_type );

			if ( is_array( self::$current_load_page_data ) && isset( self::$current_load_page_data[ $type ] ) ) {			
				return apply_filters( 'nexter_get_sections_posts_by_conditions', self::$current_load_page_data[ $type ], $type );
			}

			$current_page_type_name = $this->get_check_current_page_type_name();

			self::$current_load_page_data[ $type ] = array();

			$option['current_post_id'] = self::$current_load_page_data['ID'];

			$current_post_type	= esc_sql( get_post_type() );
			$current_post_id	= false;
			$queried_object		= get_queried_object();

			$location = isset( $option['location'] ) ? esc_sql( $option['location'] ) : '';

			/* global posts / specific posts */
			$join_meta = "pm.meta_value LIKE '%\"standard-universal\"%'";
			
			if( !empty( $current_page_type_name ) ){
				if(defined('NXT_PRO_EXT_VER')){
					$join_meta .= apply_filters('nexter_advanced_sections_query_meta', $current_page_type_name );
				}
				if($current_page_type_name == 'is_front_page'){
					$current_post_id      = esc_sql( get_the_id() );
				}else if($current_page_type_name == 'is_singular'){
					$current_post_id      = esc_sql( get_the_id() );
				}
			}else if( $current_page_type_name == '' ){
				$current_post_id = get_the_id();
			}
			
			$sqlquery = "SELECT p.ID, pm.meta_value FROM {$wpdb->postmeta} as pm INNER JOIN {$wpdb->posts} as p ON pm.post_id = p.ID WHERE (pm.meta_key = %s OR pm.meta_key = 'nxt-hooks-layout-pages') AND p.post_type = %s AND p.post_status = 'publish' AND ( {$join_meta} ) ORDER BY p.post_date DESC";
			
			$sql3 = $wpdb->prepare( $sqlquery , $location, $type );	// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared
			
			$posts  = $wpdb->get_results( $sql3 );	// phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared
			
			if( !empty($posts) ){
				foreach ( $posts as $post_data ) {
					$priority = 0;
					$post_meta_value = maybe_unserialize( $post_data->meta_value );
					
					if(!is_admin() && !empty($post_meta_value) && is_array($post_meta_value)){
						//standard match
						$standard_value = preg_grep('/^standard-/i', $post_meta_value);
						if(!empty($standard_value)){
							$priority = 5;
						}
						
						//post type match
						if ( is_object( $queried_object ) && isset($queried_object->post_type)) {
							$match_value = '/^'.$queried_object->post_type.'|entire$/i';
							$post_type_match = preg_grep($match_value, $post_meta_value);
							if(!empty($post_type_match)){
								$priority = 10;
							}
						}
						//pages match
						$check_value = preg_grep('/^default-/i', $post_meta_value);
						if(!empty($check_value)){
							$priority = 15;
						}
						
					}
					
					self::$current_load_page_data[ $type ][ $post_data->ID ] = array(
						'id'       => $post_data->ID,
						'location' => maybe_unserialize( $post_data->meta_value ),
						'priority' => ($priority) ? $priority : 0,
						'condition' => 1,
					);

					if(defined('NXT_PRO_EXT_VER')){
						self::$current_load_page_data[ $type ][ $post_data->ID ] = apply_filters('nexter_advanced_section_current_page_conditions', self::$current_load_page_data, $type, $post_data, $priority);
					}
				}
			}
			self::$current_load_page_data[$type]  = $this->array_sort_by_priority(self::$current_load_page_data[$type], 'priority', SORT_DESC);

			$option['current_post_id'] = $current_post_id;

			$this->remove_templates_excludes_conditional_rules( $type, $option );
			
			return apply_filters( 'nexter_get_sections_posts_by_conditions', self::$current_load_page_data[ $type ], $type );
		}
		
		/**
		 * Remove Tamplate Exclude Locations Conditional Rules
		 */
		public function remove_templates_excludes_conditional_rules( $type, $options ) {

			$exclusion       = isset( $options['exclusion'] ) ? $options['exclusion'] : '';
			$current_post_id = isset( $options['current_post_id'] ) ? $options['current_post_id'] : false;

			foreach ( self::$current_load_page_data[ $type ] as $c_post_id => $c_data ) {

				$exclusion_rules = get_post_meta( $c_post_id, $exclusion, true );
				$exclusion_rules = apply_filters( 'nexter_advanced_section_exclude_condition', $exclusion_rules, $c_post_id );
				
				$exclude_id = $this->check_layout_display_inc_exc_rules( $current_post_id, $exclusion_rules );
				
				if ( $exclude_id ) {
					unset( self::$current_load_page_data[ $type ][ $c_post_id ] );
				}
			}
		}

		
		
		/* 
		 *	Sorting Data Array By Priority
		 */
		public function array_sort_by_priority($data_array, $on, $order=SORT_ASC){

			$new_array = [];
			$sorting_array = [];

			if (count($data_array) > 0) {
				foreach ($data_array as $key => $val) {
					if (is_array($val)) {
						foreach ($val as $k2 => $v2) {
							if ($k2 == $on) {
								$sorting_array[$key] = $v2;
							}
						}
					} else {
						$sorting_array[$key] = $val;
					}
				}

				switch ($order) {
					case SORT_ASC:
						asort($sorting_array);
						break;
					case SORT_DESC:
						arsort($sorting_array);
						break;
				}

				foreach ($sorting_array as $key => $val) {
					if( isset($data_array[$key]['condition']) && $data_array[$key]['condition']==1 ){
						$new_array[$key] = $data_array[$key];
					}
				}
			}

			return $new_array;
		}
		

	}
}

Nexter_Builder_Display_Conditional_Rules::get_instance();