<?php
/*
 * Nexter Import
 *
 * @package Nexter Extensions
 * @since 1.0.3
 */

class Nexter_Import_Settings {
	
	/*
	 * Nexter Import Local
	 */
	public function __construct() {
		add_action( 'wp_ajax_nexter_import_data_step_4', [ $this, 'nexter_import_data_step_4' ] );
		add_action( 'wp_ajax_nexter_import_data_template', [ $this, 'nexter_import_data_template_ajax' ] );
		
	}
	
	public function nexter_import_data_template_ajax(){
		check_ajax_referer( 'nexter_admin_nonce', 'nexter_nonce' );
		
		$builder = ( isset( $_POST['builder'] ) ) ? sanitize_text_field( wp_unslash( $_POST['builder'] ) ) : '';
		$tag = ( isset( $_POST['tag'] ) ) ? sanitize_text_field( wp_unslash( $_POST['tag'] ) ) : '';
		$template = ( isset( $_POST['template'] ) ) ? sanitize_text_field( wp_unslash( $_POST['template'] ) ) : '';
		
		if( current_user_can( 'install_plugins' ) && !empty($template) && !empty($builder) && !empty($tag) && $tag=='Free'){
			$template_file = $builder.'-'.$template.'.xml';
			
			if( file_exists( NEXTER_EXT_DIR . 'include/nexter-template/template/'.$template_file ) ){
				$template_path = NEXTER_EXT_DIR . 'include/nexter-template/template/'.$template_file;
				
				if(class_exists('Nexter_Builder_Import_Export')){
				
					$import_template = new Nexter_Builder_Import_Export();
					if ( method_exists( $import_template, 'import_template_data' ) ) {
					
						$imported = $import_template->import_template_data( $template_file, $template_path );
						
						if ( is_wp_error( $imported ) ) {
							wp_send_json_error( [
								'success'	=> false,
								'message'	=> $imported->get_error_message(),
							] );
						}
						wp_send_json_success( [
								'success'	=> true,
								'content'	=> __( 'Imported', 'nexter-ext' ),
							] );
					}
					
				}
				
			}
		}else{
			wp_send_json_error( [
				'success'	=> false,
				'message'	=> __( 'oops.. Something Wrong..', 'nexter-ext' ),
			] );
		}
	}

	public function nexter_import_data_step_4(){
		check_ajax_referer( 'nexter_admin_nonce', 'nexter_nonce' );
		
		$output = '<div class="nxt-import-steps import-step-4 active" data-step="step-4">
						<svg class="success-check-circle" xmlns="http://www.w3.org/2000/svg" width="100.144" height="100.144" viewBox="0 0 128.144 128.143">
						  <path d="M72.072,8a64.072,64.072,0,1,0,64.072,64.072A64.072,64.072,0,0,0,72.072,8Zm0,12.4A51.671,51.671,0,1,1,20.4,72.072,51.643,51.643,0,0,1,72.072,20.4m36.222,33.655-5.822-5.869a3.1,3.1,0,0,0-4.384-.018L61.569,84.394,46.121,68.822a3.1,3.1,0,0,0-4.384-.018l-5.87,5.822a3.1,3.1,0,0,0-.018,4.385L59.3,102.654a3.1,3.1,0,0,0,4.384.018L108.277,58.44a3.1,3.1,0,0,0,.017-4.385Z" transform="translate(-8 -8)" fill="#45b964"/>
						</svg>
						<div class="nxt-import-heading">'.esc_html__('Success','nexter-ext').'</div>
						<div class="nxt-any-trouble">'.esc_html__('Any Troubles? ','nexter-ext').'<a href="#" class="nxt-read-article">'.esc_html__('Read Our Article','nexter-ext').'</a>
				  </div>';
		wp_send_json_success( [ 'success' => true, 'content' => $output ] );
	}
}

$Nexter_Import_Settings = new Nexter_Import_Settings();