<?php 
/**
 * Nexter Penal Settings Options
 *
 * @package Nexter Extensions
 * @since 1.0.7
 */
defined('ABSPATH') or die();
/**
 * Nexter Performace Options
 */
add_filter( 'nexter_site_performance_options', 'nexter_ext_site_performance_options' );
function nexter_ext_site_performance_options( $options ){

	$performace_option = array(
			array(
				'name' => esc_html__('Disable Emojis Script', 'nexter-ext'),
				'desc' => esc_html__('This helps you reduce extra http request for script \'wp-includes/js/wp-emoji-release.min.js\'', 'nexter-ext'),
				'id'   => 'disable_emoji_scripts',
				'type' => 'checkbox',
			),
			
			array(
				'name' => esc_html__('Disable Embeds', 'nexter-ext'),
				'desc' => esc_html__('This helps you reduce extra http request for script \'wp-embed.min.js\', which is not required in most cases. As this, JS generate links previews.', 'nexter-ext'),
				'id'   => 'disable_embeds',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__('Disable Dashicons', 'nexter-ext'),
				'desc' => esc_html__('This helps you reduce extra http request for script \'dashicons.min.css\' in frontend, which helps in fixing render blocking.', 'nexter-ext'),
				'id'   => 'disable_dashicons',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__('Remove RSD Link', 'nexter-ext'),
				'desc' => esc_html__('Helps you clean unnecessary codes from WordPress header, RSD links aren\'t needed unless you publish your blog from other apps', 'nexter-ext'),
				'id'   => 'disable_rsd_link',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__('Remove wlwmanifest Link', 'nexter-ext'),
				'desc' => esc_html__('Helps you clean unnecessary codes from WordPress header, if you dont use Windows Live Writer, you can remove such links.', 'nexter-ext'),
				'id'   => 'disable_wlwmanifest_link',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__('Remove Shortlink', 'nexter-ext'),
				'desc' => esc_html__('This helps you remove unnecessary shortlinks tag from post/pages url.', 'nexter-ext'),
				'id'   => 'disable_shortlink',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__('Disable RSS Feeds', 'nexter-ext'),
				'desc' => esc_html__('Helps you clean unnecessary codes from WordPress header, if you dont use Windows Live Writer, you can remove such links.', 'nexter-ext'),
				'id'   => 'disable_rss_feeds',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__('Remove RSS Feed Links', 'nexter-ext'),
				'desc' => esc_html__('If you don\'t use your WordPress for blogging then you can remove WordPress RSS feeds to get rid of those extra code', 'nexter-ext'),
				'id'   => 'disable_rss_feed_link',
				'type' => 'checkbox',
			),
			array(
				'name' => esc_html__('Disable Self Pingbacks', 'nexter-ext'),
				'desc' => esc_html__('Declutter your comment\'s section by avoiding ping to the articles from your same site', 'nexter-ext'),
				'id'   => 'disable_self_pingbacks',
				'type' => 'checkbox',
			),
			
			array(
				'name' => esc_html__('Comments', 'nexter-ext'),
				'desc' => esc_html__('If you\'re not using WordPress comments, then it\'s better to completely remove them to avoid any spam submission.', 'nexter-ext'),
				'id'   => 'disable_comments',
				'type' => 'select',
				'default' => 'none',
				'options' => array(
					'' => esc_html__('Enabled', 'nexter-ext'),
					'all' => esc_html__('Disable Everywhere', 'nexter-ext'),
					'custom' => esc_html__('Disable Specific Post Type', 'nexter-ext'),
				),
			),
			array(
				'name'    => esc_html__('Disable Comments Post Type Wise','nexter-ext'),
				'desc'    => '',
				'id'      => 'disble_custom_post_comments',
				'type'    => 'multicheck_inline',
				'options_cb' => 'nexter_ext_get_post_type_list',
				'select_all_button' => false,
				'attributes' => array(
					'data-conditional-id'    => 'disable_comments',
					'data-conditional-value' => 'custom',
				),
			),
			array(
				'name' => esc_html__('Disable Password Strength Meter', 'nexter-ext'),
				'desc' => esc_html__('This removes Strong Password Generator scripts, which forces users to make a strong password. Using this, you can remove unnecessary requests to load site-wide.', 'nexter-ext'),
				'id'   => 'disable_pw_strength_meter',
				'type' => 'checkbox',
			),
			
		);
		
	return array_merge($options, $performace_option);
}
function nexter_ext_get_post_type_list(){
	$args = array(
		'public'   => true,
		'show_ui' => true
	);	 
	$post_types = get_post_types( $args, 'objects' );
	$options = array();
	foreach ( $post_types  as $post_type ) {
		$exclude = array( 'elementor_library' );
		if( TRUE === in_array( $post_type->name, $exclude ) )
		  continue;
	  
		$options[$post_type->name] = $post_type->label; 
	}
	
	return $options;
}
add_filter( 'nexter_site_security_options', 'nexter_ext_site_security_options' );
function nexter_ext_site_security_options( $options ){
	$security_option = array(
		array(
			'name' => esc_html__('Disable XML-RPC', 'nexter-ext'),
			'desc' => esc_html__('For Security reasons, it\'s better to disable XML-RPC on your site, unless you publish content from WordPress mobile app or use Jetpack plugins.', 'nexter-ext'),
			'id'   => 'disable_xml_rpc',
			'type' => 'checkbox',
		),
		array(
			'name' => esc_html__('Disable WP Version Generator', 'nexter-ext'),
			'desc' => esc_html__('For better security, it\'s always safe to remove the WordPress version from your site header. This helps in hiding the WordPress version.', 'nexter-ext'),
			'id'   => 'disable_wp_version',
			'type' => 'checkbox',
		),
		array(
			'name' => esc_html__('Disable REST API', 'nexter-ext'),
			'desc' => esc_html__('For better security, it\'s always safe to disable Rest API when not needed. Some plugins like Gutenberg, Yoast SEO do require this to work properly. Hence, choosing Disable for Non-Admins will be the best option.', 'nexter-ext'),
			'id'   => 'disable_rest_api',
			'type' => 'select',
			'default' => '',
			'options' => array(
				'' => esc_html__('Enabled', 'nexter-ext'),
				'non_admin' => esc_html__('Disable for Non-Admin', 'nexter-ext'),
				'logged_out' => esc_html__('Disable When Logged Out', 'nexter-ext'),
			),
		),
		array(
			'name' => esc_html__('Remove REST API Links', 'nexter-ext'),
			'desc' => esc_html__('This helps you remove unnecessary REST API tags from endpoints', 'nexter-ext'),
			'id'   => 'disable_rest_api_links',
			'type' => 'checkbox',
		),
		array(
			'before_row' => '<div class="nxt-custom-login-url-wrap"><div class="nxt-custom-label">'.esc_html__('Custom Login Url','nexter-ext').'</div><div class="nxt-custom-login-url-inner">',
			'name' => esc_html__('Redirect Login URL', 'nexter-ext'),
			'desc' => esc_html__('Hide your WordPress default wp-admin URL path from public access.', 'nexter-ext'),
			'id'   => 'custom_login_url',
			'type' => 'text',
			'attributes' => array(
				'pattern' => '^[a-z0-9-]+$',
			),
		),
		array(
			'name' => esc_html__('Login URL Behaviour', 'nexter-ext'),
			'desc' => esc_html__('Redirect old Wp-admin path to different pages, after changing to your new url', 'nexter-ext'),
			'id'   => 'disable_login_url_behavior',
			'type' => 'select',
			'default' => 'message',
			'options' => array(
				'message' => esc_html__('Message (Default)', 'nexter-ext'),
				'home_page' => esc_html__('Home Page', 'nexter-ext'),
				'404_page' => esc_html__('404 Page Template', 'nexter-ext'),
			),
		),
		array(
			'name' => esc_html__('Login Page Message', 'nexter-ext'),
			'desc' => esc_html__('Add your custom message here, which will be shown when someone visits old wp-admin path for login', 'nexter-ext'),
			'id'   => 'login_page_message',
			'type' => 'textarea_small',
			'attributes' => array(
				'rows' => 2,
				'data-conditional-id'    => 'disable_login_url_behavior',
				'data-conditional-value' => 'message',
			),
			'after_row' => '</div></div>',
		),
	);
	return array_merge($options, $security_option);
}
/*
 * Nexter Performance Options Disable
 * @since 1.0.11
 */
$nxt_site_performance = get_option( 'nexter_site_performance' );
$nxt_site_security = get_option( 'nexter_site_security' );

/*Disable Emojis Scripts*/
if( !empty( $nxt_site_performance['disable_emoji_scripts'] ) && $nxt_site_performance['disable_emoji_scripts'] === 'on' ) {
	add_action( 'init', 'nxt_disable_emojis' );
}
function nxt_disable_emojis() {
	remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
	remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
	remove_action( 'wp_print_styles', 'print_emoji_styles' );
	remove_action( 'admin_print_styles', 'print_emoji_styles' ); 
	remove_filter( 'the_content_feed', 'wp_staticize_emoji' );
	remove_filter( 'comment_text_rss', 'wp_staticize_emoji' ); 
	remove_filter( 'wp_mail', 'wp_staticize_emoji_for_email' );
	
	add_filter('tiny_mce_plugins', function ($plugins) {
		if (is_array($plugins)) {
			return array_diff($plugins, array('wpemoji'));
		} else {
			return array();
		}
	});

	add_filter('wp_resource_hints', function ($urls, $relation_type) {
		if ('dns-prefetch' === $relation_type) {
			/** This filter is documented in wp-includes/formatting.php */
			$emoji_svg_url = apply_filters('emoji_svg_url', 'https://s.w.org/images/core/emoji/2/svg/');

			$urls = array_diff($urls, array($emoji_svg_url));
		}

		return $urls;
	}, 10, 2);
}

/*Disable XML-RPC*/
if( !empty( $nxt_site_security['disable_xml_rpc'] ) && $nxt_site_security['disable_xml_rpc'] === 'on' ){
	add_filter('xmlrpc_enabled', '__return_false');
	add_filter('wp_headers', 'nxt_remove_x_pingback');
	add_filter('pings_open', '__return_false', 9999);
}
function nxt_remove_x_pingback($headers) {
    unset($headers['X-Pingback'], $headers['x-pingback']);
    return $headers;
}

/*Disable Embeds*/
if(!empty($nxt_site_performance['disable_embeds']) && $nxt_site_performance['disable_embeds'] === 'on') {
	add_action('init', 'nxt_disable_embeds', 9999);
}
function nxt_disable_embeds(){
	global $wp;
	$wp->public_query_vars = array_diff($wp->public_query_vars, array('embed'));
	add_filter('embed_oembed_discover', '__return_false');
	remove_filter('oembed_dataparse', 'wp_filter_oembed_result', 10);
	remove_action('wp_head', 'wp_oembed_add_discovery_links');
	remove_action('wp_head', 'wp_oembed_add_host_js');
	add_filter('tiny_mce_plugins', function( $plugins ) {
		return array_diff($plugins, array('wpembed'));
	});
	add_filter('rewrite_rules_array', function($rules) {
		foreach($rules as $rule => $rewrite) {
			if(false !== strpos($rewrite, 'embed=true')) {
				unset($rules[$rule]);
			}
		}
		return $rules;
	});
	remove_filter('pre_oembed_result', 'wp_filter_pre_oembed_result', 10);
}

/*Remove RSD Link*/
if(!empty($nxt_site_performance['disable_rsd_link']) && $nxt_site_performance['disable_rsd_link'] === 'on' ) {
	remove_action('wp_head', 'rsd_link');
}

/*Remove wlwmanifest Link*/
if(!empty($nxt_site_performance['disable_wlwmanifest_link']) && $nxt_site_performance['disable_wlwmanifest_link'] === 'on' ) {
	remove_action('wp_head', 'wlwmanifest_link');
}

/*Remove Shortlink Link*/
if(!empty($nxt_site_performance['disable_shortlink']) && $nxt_site_performance['disable_shortlink'] === 'on' ) {
	remove_action('wp_head', 'wp_shortlink_wp_head');
	remove_action ('template_redirect', 'wp_shortlink_header', 11, 0);
}

/*Remove RSS Feeds*/
if(!empty($nxt_site_performance['disable_rss_feeds']) && $nxt_site_performance['disable_rss_feeds'] === 'on' ) {
	add_action('template_redirect', 'nxt_disable_rss_feeds', 1);
}
function nxt_disable_rss_feeds() {
	if(!is_feed() || is_404()) {
		return;
	}
	
	global $wp_rewrite;
	global $wp_query;

	//check for GET feed variable
	if(isset($_GET['feed'])) {
		wp_redirect(esc_url_raw(remove_query_arg('feed')), 301);
		exit;
	}

	//unset/remove wp_query feed variable
	if(get_query_var('feed') !== 'old') {
		set_query_var('feed', '');
	}
		
	//Wp redirect to the proper URL
	redirect_canonical();

	//redirect failed url, show error message
	wp_die(sprintf(__("No feed available, please visit the <a href='%s'>Home Page</a>!",'nexter-ext'), esc_url(home_url('/'))));
}

/*Remove RSS Feed Links*/
if(!empty($nxt_site_performance['disable_rss_feed_link']) && $nxt_site_performance['disable_rss_feed_link'] === 'on' ) {
	remove_action('wp_head', 'feed_links_extra', 3);
	remove_action('wp_head', 'feed_links', 2);
}

/*Disable DashIcons*/
if(!empty($nxt_site_performance['disable_dashicons']) && $nxt_site_performance['disable_dashicons'] === 'on' ) {
	add_action('wp_enqueue_scripts', 'nxt_disable_dashicons');
	function nxt_disable_dashicons(){
		if(!is_user_logged_in()) {
			wp_dequeue_style('dashicons');
			wp_deregister_style('dashicons');
		}
	}
}

/*Disable Self Pingbacks*/
if(!empty($nxt_site_performance['disable_self_pingbacks']) && $nxt_site_performance['disable_self_pingbacks'] === 'on' ) {
	add_action('pre_ping', 'nxt_disable_self_pingbacks');
}
function nxt_disable_self_pingbacks( &$links ){
	$home = home_url();
	foreach($links as $l => $link) {
		if(strpos($link, $home) === 0) {
			unset($links[$l]);
		}
	}
}

/*Disable WP Version*/
if(!empty($nxt_site_security['disable_wp_version']) && $nxt_site_security['disable_wp_version'] === 'on' ) {
	remove_action('wp_head', 'wp_generator');
	add_filter('the_generator', function(){
		return '';
	});
}

/*Disable REST API*/
if(!empty($nxt_site_security['disable_rest_api'])) {
	
	add_filter( 'rest_authentication_errors', function( $result ) {
		if(!empty($result)) {
			return $result;
		}else{
			global $nxt_site_security;
			$check_disabled = false;

			//get rest route
			$rest_route = $GLOBALS['wp']->query_vars['rest_route'];

			//check rest route for exceptions
			if(strpos($rest_route, 'contact-form-7') !== false) {
				return;
			}

			//check options
			if($nxt_site_security['disable_rest_api'] == 'non_admin' && !current_user_can('manage_options')) {
				$check_disabled = true;
			}else if($nxt_site_security['disable_rest_api'] == 'logged_out' && !is_user_logged_in()) {
				// Return an error if user is not logged in.
				$check_disabled = true;
			}
		}
		if($check_disabled) {
			return new WP_Error('rest_authentication_error', __('Sorry, do not have permission REST API requests.', 'nexter-ext'), array('status' => 401));
		}
		
		// on logged-in requests
		return $result;
		
	}, 20);
}

/*Disable REST API Links*/
if(!empty($nxt_site_security['disable_rest_api_links']) && $nxt_site_security['disable_rest_api_links'] === 'on' ) {
	remove_action('wp_head', 'rest_output_link_wp_head');
	remove_action('xmlrpc_rsd_apis', 'rest_output_rsd');
	remove_action('template_redirect', 'rest_output_link_header', 11, 0);
}

/*Disable Password Strength Meter*/
if(!empty($nxt_site_performance['disable_pw_strength_meter']) && $nxt_site_performance['disable_pw_strength_meter'] === 'on' ) {
	add_action('wp_print_scripts', function(){
		//admin
		if( is_admin() ) {
			return;
		}
		
		//wp-login.php
		if( ( isset($GLOBALS['pagenow']) && $GLOBALS['pagenow'] === 'wp-login.php' ) || ( isset($_GET['action']) && in_array($_GET['action'], array('register','rp', 'lostpassword' )) ) ) {
			return;
		}

		//woocommerce
		if( class_exists('WooCommerce') && (is_account_page() || is_checkout()) ) {
			return;
		}
		
		wp_dequeue_script('password-strength-meter');
		wp_deregister_script('password-strength-meter');

		wp_dequeue_script('wc-password-strength-meter');
		wp_deregister_script('wc-password-strength-meter');
		
		wp_dequeue_script('zxcvbn-async');
		wp_deregister_script('zxcvbn-async');
		
	}, 100);
}

/*Disable Comments Entire Site*/
if(!empty($nxt_site_performance['disable_comments']) && $nxt_site_performance['disable_comments'] === 'all' ) {
	//Disable Built-in Recent Comments Widget
	add_action('widgets_init', function(){
		unregister_widget('WP_Widget_Recent_Comments');
		add_filter('show_recent_comments_widget_style', '__return_false');
	});
	
	if( !isset( $nxt_site_performance['disable_rss_feed_link'] ) ){
		// feed_links_extra inserts a comments RSS link.
		remove_action('wp_head', 'feed_links_extra', 3);
	}
	
	if( !isset( $nxt_site_security['disable_xml_rpc'] ) ){
		add_filter('wp_headers', 'nxt_remove_x_pingback');
	}
	
	//Disable 403 for all comment feed requests
	add_action('template_redirect', function(){
		if(is_comment_feed()) {
			wp_die(__('Comments are disabled.', 'nexter-ext'), '', array('response' => 403));
		}
	}, 9);
	
	//Remove Comment Admin bar filtering
	add_action('template_redirect', 'nxt_filter_admin_bar');
	add_action('admin_init', 'nxt_filter_admin_bar');
	
	add_filter('rest_endpoints', 'nxt_filter_rest_endpoints');
	
}

if(!empty($nxt_site_performance['disable_comments']) && ($nxt_site_performance['disable_comments'] === 'custom' || $nxt_site_performance['disable_comments'] === 'all')){
	add_action('wp_loaded', 'nxt_wp_loaded_comments');
}

//Disable Comments REST API Endpoint
function nxt_filter_rest_endpoints( $endpoints ){
	unset($endpoints['comments']);
	return $endpoints;
}

//Remove comments links from admin bar.
function nxt_filter_admin_bar(){
	if (is_admin_bar_showing()) {
		remove_action('admin_bar_menu', 'wp_admin_bar_comments_menu', 60);
		if (is_multisite()) {
			add_action('admin_bar_menu', 'nxt_remove_network_comment_links', 500);
		}
	}
}

//Remove Comment Links from the Multisite(Network) Admin Bar
function nxt_remove_network_comment_links($wp_admin_bar) {
	if(!function_exists('is_plugin_active_for_network')) {
	    require_once(ABSPATH . '/wp-admin/includes/plugin.php');
	}
	if(is_plugin_active_for_network('nexter-extension/nexter-extension.php') && is_user_logged_in()) {
		//Remove for All
		foreach($wp_admin_bar->user->blogs as $blog) {
			$wp_admin_bar->remove_menu('blog-' . $blog->userblog_id . '-c');
		}
	} else {
		//Remove for Current
		$wp_admin_bar->remove_menu('blog-' . get_current_blog_id() . '-c');
	}
}

function nxt_wp_loaded_comments(){
	global $nxt_site_performance;
	//All Post Types Remove Support Comments
	$all_post_types = [];
	if(!empty($nxt_site_performance['disable_comments']) && $nxt_site_performance['disable_comments'] === 'all'){
		$all_post_types = get_post_types( array('public' => true), 'names' );
	}else if(!empty($nxt_site_performance['disable_comments']) && $nxt_site_performance['disable_comments'] === 'custom'){
		$all_post_types = nxt_get_disabled_post_types();
	}
	if(!empty($all_post_types)) {
		foreach($all_post_types as $post_type) {
			if(post_type_supports($post_type, 'comments')) {
				remove_post_type_support($post_type, 'comments');
				remove_post_type_support($post_type, 'trackbacks');
			}
		}
	}

	add_filter('comments_array', function($comments, $post_id) { 
		global $nxt_site_performance;
		$post_type = get_post_type($post_id);
		return ($nxt_site_performance['disable_comments'] === 'all' || nxt_comment_post_type_disabled($post_type)  ? array() : $comments);
	}, 20, 2);
	add_filter('comments_open', function($open, $post_id) {
		global $nxt_site_performance;
		$post_type = get_post_type($post_id);
		return ($nxt_site_performance['disable_comments'] === 'all' || nxt_comment_post_type_disabled($post_type) ? false : $open); 
	}, 20, 2);
	add_filter('pings_open', function($count, $post_id) {
		global $nxt_site_performance;
		$post_type = get_post_type($post_id);
		return ($nxt_site_performance['disable_comments'] === 'all' || nxt_comment_post_type_disabled($post_type) ? 0 : $count);
	}, 20, 2);

	if(is_admin()) {
		
		if(!empty($nxt_site_performance['disable_comments']) && $nxt_site_performance['disable_comments'] === 'all'){
		
			//Remove Menu Links And Disable Admin Pages 
			add_action('admin_menu', 'nxt_admin_menu_comments', 9999);
		
		
			//Hide Css Comments from Dashboard
			add_action('admin_print_styles-index.php', function(){
				echo "<style>#dashboard_right_now .comment-count, #dashboard_right_now .comment-mod-count, #latest-comments, #welcome-panel .welcome-comments {
						display: none !important;
					}
				</style>";
			});

			//Hide Css Comments from Profile
			add_action('admin_print_styles-profile.php', function(){
				echo "<style>.user-comment-shortcuts-wrap {
						display: none !important;
					}
				</style>";
			});
		
			//Recent Comments Meta
			add_action('wp_dashboard_setup', 'nxt_recent_comments_dashboard');
			
			//Pingback Flag
			add_filter('pre_option_default_pingback_flag', '__return_zero');
		}
	} else {
		
		add_action('template_redirect', 'nxt_comment_template');
		
		if(!empty($nxt_site_performance['disable_comments']) && $nxt_site_performance['disable_comments'] === 'all'){
			//Disable the Comments Feed Link
			add_filter('feed_links_show_comments_feed', '__return_false');
		}
	}
}

function nxt_get_disabled_post_types(){
	global $nxt_site_performance;
	$post_types = [];
	if(!empty($nxt_site_performance['disable_comments']) && $nxt_site_performance['disable_comments'] === 'custom'){
		if(!empty($nxt_site_performance['disble_custom_post_comments'])){
			$post_types = $nxt_site_performance['disble_custom_post_comments'];
		}
	}
	return $post_types;
}

function nxt_comment_post_type_disabled( $post_type ){
	return $post_type && in_array($post_type, nxt_get_disabled_post_types());
}
function nxt_comment_template(){
	global $nxt_site_performance;
	if (is_singular() && (!empty($nxt_site_performance['disable_comments']) && ( $nxt_site_performance['disable_comments'] === 'all' || ($nxt_site_performance['disable_comments'] === 'custom' && nxt_comment_post_type_disabled(get_post_type())) ) )) {
		if (!defined('DISABLE_COMMENTS_REMOVE_COMMENTS_TEMPLATE') || DISABLE_COMMENTS_REMOVE_COMMENTS_TEMPLATE == true) {
			//Replace Comments Template
			add_filter('comments_template', 'nxt_empty_comments_template', 20);
		}
		//Remove Script Comment Reply
		wp_deregister_script('comment-reply');
		
		// feed_links_extra inserts a comments RSS link.
		remove_action('wp_head', 'feed_links_extra', 3);
	}
}

function nxt_recent_comments_dashboard(){
	remove_meta_box('dashboard_recent_comments', 'dashboard', 'normal');
}

//Empty(Blank) Comment Template
function nxt_empty_comments_template(){
	return dirname(__FILE__) . '/comments.php';
}

//Admin Bar Menu Comments
function nxt_admin_menu_comments(){
	global $pagenow;

	//Remove Comment Menu Links
	remove_menu_page('edit-comments.php');

	//Disable Comments Pages
	if($pagenow == 'comment.php' || $pagenow == 'edit-comments.php') {
		wp_die(__('Comments are disabled.', 'nexter-ext'), '', array('response' => 403));
	}

	//Disable Discussion Page
	if($pagenow == 'options-discussion.php') {
		wp_die(__('Comments are disabled.', 'nexter-ext'), '', array('response' => 403));
	}
	//Remove Discussion Menu Links
	remove_submenu_page('options-general.php', 'options-discussion.php');
}